@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014-2018 Free Software Foundation, Inc.
+# Copyright (C) 2014-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ srcdir=${srcdir:-.}
 # Follow an index entry in a split file
 
 run_ginfo -f split
-printf 'ientry text\r\rDq' >$pty_type
+printf 'ientry text\r\rDq' >&7
 timeout_test
 
 if test ! -f $ginfo_output; then
