@@ -59,16 +59,12 @@ $result_trees{'consecutive_conditionals'} = {
                       }
                     },
                     'source_info' => {
-                      'file_name' => '',
-                      'line_nr' => 3,
-                      'macro' => ''
+                      'line_nr' => 3
                     }
                   }
                 ],
                 'source_info' => {
-                  'file_name' => '',
-                  'line_nr' => 1,
-                  'macro' => ''
+                  'line_nr' => 1
                 }
               },
               'sourcemark_type' => 'ignored_conditional_block'
@@ -121,16 +117,12 @@ $result_trees{'consecutive_conditionals'} = {
                       }
                     },
                     'source_info' => {
-                      'file_name' => '',
-                      'line_nr' => 6,
-                      'macro' => ''
+                      'line_nr' => 6
                     }
                   }
                 ],
                 'source_info' => {
-                  'file_name' => '',
-                  'line_nr' => 4,
-                  'macro' => ''
+                  'line_nr' => 4
                 }
               },
               'sourcemark_type' => 'ignored_conditional_block'
@@ -215,9 +207,7 @@ $result_trees{'consecutive_conditionals'} = {
                       }
                     },
                     'source_info' => {
-                      'file_name' => '',
-                      'line_nr' => 12,
-                      'macro' => ''
+                      'line_nr' => 12
                     }
                   }
                 ],
@@ -227,9 +217,7 @@ $result_trees{'consecutive_conditionals'} = {
                   }
                 },
                 'source_info' => {
-                  'file_name' => '',
-                  'line_nr' => 10,
-                  'macro' => ''
+                  'line_nr' => 10
                 }
               },
               'position' => 1,
@@ -288,9 +276,7 @@ $result_trees{'consecutive_conditionals'} = {
                       }
                     },
                     'source_info' => {
-                      'file_name' => '',
-                      'line_nr' => 15,
-                      'macro' => ''
+                      'line_nr' => 15
                     }
                   }
                 ],
@@ -300,9 +286,7 @@ $result_trees{'consecutive_conditionals'} = {
                   }
                 },
                 'source_info' => {
-                  'file_name' => '',
-                  'line_nr' => 13,
-                  'macro' => ''
+                  'line_nr' => 13
                 }
               },
               'position' => 1,
