@@ -19,10 +19,16 @@ $result_trees{'inlineiffmtifelse_not_closed_three_arg'} = {
                       'text' => 'html'
                     }
                   ],
-                  'type' => 'brace_command_arg'
+                  'type' => 'brace_arg'
                 },
                 {
-                  'type' => 'elided'
+                  'contents' => [
+                    {
+                      'text' => ' hhhhh',
+                      'type' => 'raw'
+                    }
+                  ],
+                  'type' => 'elided_brace_command_arg'
                 },
                 {
                   'contents' => [
@@ -31,10 +37,12 @@ $result_trees{'inlineiffmtifelse_not_closed_three_arg'} = {
 '
                     }
                   ],
-                  'extra' => {
-                    'spaces_before_argument' => ' '
+                  'info' => {
+                    'spaces_before_argument' => {
+                      'text' => ' '
+                    }
                   },
-                  'type' => 'brace_command_arg'
+                  'type' => 'brace_arg'
                 }
               ],
               'cmdname' => 'inlinefmtifelse',
@@ -43,9 +51,7 @@ $result_trees{'inlineiffmtifelse_not_closed_three_arg'} = {
                 'format' => 'html'
               },
               'source_info' => {
-                'file_name' => '',
-                'line_nr' => 1,
-                'macro' => ''
+                'line_nr' => 1
               }
             }
           ],
@@ -58,7 +64,7 @@ $result_trees{'inlineiffmtifelse_not_closed_three_arg'} = {
   'type' => 'document_root'
 };
 
-$result_texis{'inlineiffmtifelse_not_closed_three_arg'} = '@inlinefmtifelse{html,, ggggg
+$result_texis{'inlineiffmtifelse_not_closed_three_arg'} = '@inlinefmtifelse{html, hhhhh, ggggg
 }';
 
 
@@ -69,9 +75,7 @@ $result_errors{'inlineiffmtifelse_not_closed_three_arg'} = [
   {
     'error_line' => '@inlinefmtifelse missing closing brace
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@inlinefmtifelse missing closing brace',
     'type' => 'error'
   }
