@@ -90,9 +90,7 @@ $result_trees{'nested_ignore'} = {
             }
           ],
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 1,
-            'macro' => ''
+            'line_nr' => 1
           }
         }
       ],
@@ -125,9 +123,7 @@ $result_errors{'nested_ignore'} = [
   {
     'error_line' => 'no matching `@end ignore\'
 ',
-    'file_name' => '',
     'line_nr' => 14,
-    'macro' => '',
     'text' => 'no matching `@end ignore\'',
     'type' => 'error'
   }
