@@ -10,10 +10,17 @@ $result_trees{'unknown_value'} = {
     {
       'contents' => [
         {
-          'cmdname' => 'value',
-          'extra' => {
-            'flag' => 'unknown'
-          }
+          'args' => [
+            {
+              'contents' => [
+                {
+                  'text' => 'unknown'
+                }
+              ],
+              'type' => 'brace_container'
+            }
+          ],
+          'cmdname' => 'value'
         }
       ],
       'type' => 'before_node_section'
@@ -25,15 +32,13 @@ $result_trees{'unknown_value'} = {
 $result_texis{'unknown_value'} = '@value{unknown}';
 
 
-$result_texts{'unknown_value'} = '';
+$result_texts{'unknown_value'} = 'unknown';
 
 $result_errors{'unknown_value'} = [
   {
     'error_line' => 'warning: undefined flag: unknown
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => 'undefined flag: unknown',
     'type' => 'warning'
   }
@@ -44,7 +49,7 @@ $result_floats{'unknown_value'} = {};
 
 
 
-$result_converted{'plaintext'}->{'unknown_value'} = '{No value for ‘unknown’}
+$result_converted{'plaintext'}->{'unknown_value'} = '{No value for \'unknown\'}
 ';
 
 
