@@ -35,10 +35,10 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
                 }
               ],
               'cmdname' => 'contents',
+              'extra' => {},
               'source_info' => {
                 'file_name' => 'double_contents.texi',
-                'line_nr' => 3,
-                'macro' => ''
+                'line_nr' => 3
               }
             },
             {
@@ -71,6 +71,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       ],
       'cmdname' => 'node',
       'extra' => {
+        'is_target' => 1,
         'normalized' => 'Top'
       },
       'info' => {
@@ -80,8 +81,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 5,
-        'macro' => ''
+        'line_nr' => 5
       }
     },
     {
@@ -149,9 +149,11 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
                     }
                   ],
                   'extra' => {
-                    'node_content' => [
-                      {}
-                    ],
+                    'node_content' => {
+                      'contents' => [
+                        {}
+                      ]
+                    },
                     'normalized' => 'chapter'
                   },
                   'type' => 'menu_entry_node'
@@ -177,8 +179,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
               ],
               'source_info' => {
                 'file_name' => 'double_contents.texi',
-                'line_nr' => 11,
-                'macro' => ''
+                'line_nr' => 11
               },
               'type' => 'menu_entry'
             },
@@ -210,15 +211,13 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
               },
               'source_info' => {
                 'file_name' => 'double_contents.texi',
-                'line_nr' => 12,
-                'macro' => ''
+                'line_nr' => 12
               }
             }
           ],
           'source_info' => {
             'file_name' => 'double_contents.texi',
-            'line_nr' => 10,
-            'macro' => ''
+            'line_nr' => 10
           }
         },
         {
@@ -235,8 +234,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 6,
-        'macro' => ''
+        'line_nr' => 6
       }
     },
     {
@@ -258,6 +256,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       ],
       'cmdname' => 'node',
       'extra' => {
+        'is_target' => 1,
         'normalized' => 'chapter'
       },
       'info' => {
@@ -267,8 +266,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 14,
-        'macro' => ''
+        'line_nr' => 14
       }
     },
     {
@@ -304,10 +302,10 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
             }
           ],
           'cmdname' => 'contents',
+          'extra' => {},
           'source_info' => {
             'file_name' => 'double_contents.texi',
-            'line_nr' => 17,
-            'macro' => ''
+            'line_nr' => 17
           }
         },
         {
@@ -351,9 +349,11 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
                     }
                   ],
                   'extra' => {
-                    'node_content' => [
-                      {}
-                    ],
+                    'node_content' => {
+                      'contents' => [
+                        {}
+                      ]
+                    },
                     'normalized' => 'section'
                   },
                   'type' => 'menu_entry_node'
@@ -379,8 +379,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
               ],
               'source_info' => {
                 'file_name' => 'double_contents.texi',
-                'line_nr' => 21,
-                'macro' => ''
+                'line_nr' => 21
               },
               'type' => 'menu_entry'
             },
@@ -412,15 +411,13 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
               },
               'source_info' => {
                 'file_name' => 'double_contents.texi',
-                'line_nr' => 22,
-                'macro' => ''
+                'line_nr' => 22
               }
             }
           ],
           'source_info' => {
             'file_name' => 'double_contents.texi',
-            'line_nr' => 20,
-            'macro' => ''
+            'line_nr' => 20
           }
         },
         {
@@ -429,7 +426,9 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
           'type' => 'empty_line'
         }
       ],
-      'extra' => {},
+      'extra' => {
+        'section_number' => '1'
+      },
       'info' => {
         'spaces_before_argument' => {
           'text' => ' '
@@ -437,8 +436,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 15,
-        'macro' => ''
+        'line_nr' => 15
       }
     },
     {
@@ -460,6 +458,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       ],
       'cmdname' => 'node',
       'extra' => {
+        'is_target' => 1,
         'normalized' => 'section'
       },
       'info' => {
@@ -469,8 +468,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 24,
-        'macro' => ''
+        'line_nr' => 24
       }
     },
     {
@@ -501,10 +499,10 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
             }
           ],
           'cmdname' => 'contents',
+          'extra' => {},
           'source_info' => {
             'file_name' => 'double_contents.texi',
-            'line_nr' => 26,
-            'macro' => ''
+            'line_nr' => 26
           }
         },
         {
@@ -513,7 +511,9 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
           'type' => 'empty_line'
         }
       ],
-      'extra' => {},
+      'extra' => {
+        'section_number' => '1.1'
+      },
       'info' => {
         'spaces_before_argument' => {
           'text' => ' '
@@ -521,8 +521,7 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
       },
       'source_info' => {
         'file_name' => 'double_contents.texi',
-        'line_nr' => 25,
-        'macro' => ''
+        'line_nr' => 25
       }
     },
     {
@@ -538,8 +537,8 @@ $result_trees{'double_contents_after_title_show_title_nodes'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[4]{'contents'}[4]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[4]{'contents'}[4]{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}{'contents'}[0] = $result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[4]{'contents'}[4]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}{'contents'}[0] = $result_trees{'double_contents_after_title_show_title_nodes'}{'contents'}[4]{'contents'}[4]{'contents'}[0]{'contents'}[1]{'contents'}[0];
 
 $result_texis{'double_contents_after_title_show_title_nodes'} = '\\input texinfo @c -*-texinfo-*-
 
@@ -593,7 +592,7 @@ The chapter
 ';
 
 $result_sectioning{'double_contents_after_title_show_title_nodes'} = {
-  'structure' => {
+  'extra' => {
     'section_childs' => [
       {
         'cmdname' => 'top',
@@ -602,11 +601,8 @@ $result_sectioning{'double_contents_after_title_show_title_nodes'} = {
             'cmdname' => 'node',
             'extra' => {
               'normalized' => 'Top'
-            },
-            'structure' => {}
-          }
-        },
-        'structure' => {
+            }
+          },
           'section_childs' => [
             {
               'cmdname' => 'chapter',
@@ -615,11 +611,8 @@ $result_sectioning{'double_contents_after_title_show_title_nodes'} = {
                   'cmdname' => 'node',
                   'extra' => {
                     'normalized' => 'chapter'
-                  },
-                  'structure' => {}
-                }
-              },
-              'structure' => {
+                  }
+                },
                 'section_childs' => [
                   {
                     'cmdname' => 'section',
@@ -628,135 +621,125 @@ $result_sectioning{'double_contents_after_title_show_title_nodes'} = {
                         'cmdname' => 'node',
                         'extra' => {
                           'normalized' => 'section'
-                        },
-                        'structure' => {}
-                      }
-                    },
-                    'structure' => {
+                        }
+                      },
+                      'section_directions' => {
+                        'up' => {}
+                      },
                       'section_level' => 2,
-                      'section_number' => '1.1',
-                      'section_up' => {}
+                      'section_number' => '1.1'
                     }
                   }
                 ],
+                'section_directions' => {
+                  'up' => {}
+                },
                 'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
+                'section_number' => '1',
+                'toplevel_directions' => {
+                  'prev' => {},
+                  'up' => {}
+                }
               }
             }
           ],
           'section_level' => 0,
-          'section_up' => {}
+          'sectioning_root' => {},
+          'toplevel_directions' => {}
         }
       }
     ],
     'section_level' => -1
   }
 };
-$result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'double_contents_after_title_show_title_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'};
+$result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_directions'}{'up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0];
+$result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_directions'}{'up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'toplevel_directions'}{'prev'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'toplevel_directions'}{'up'} = $result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'double_contents_after_title_show_title_nodes'}{'extra'}{'section_childs'}[0]{'extra'}{'sectioning_root'} = $result_sectioning{'double_contents_after_title_show_title_nodes'};
 
-$result_nodes{'double_contents_after_title_show_title_nodes'} = {
-  'cmdname' => 'node',
-  'extra' => {
-    'associated_section' => {
-      'cmdname' => 'top',
-      'extra' => {},
-      'structure' => {}
-    },
-    'menus' => [
-      {
-        'cmdname' => 'menu'
-      }
-    ],
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'associated_section' => {
-          'cmdname' => 'chapter',
-          'extra' => {},
-          'structure' => {
-            'section_number' => 1
-          }
-        },
-        'menus' => [
-          {
-            'cmdname' => 'menu'
-          }
-        ],
-        'normalized' => 'chapter'
+$result_nodes{'double_contents_after_title_show_title_nodes'} = [
+  {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'top',
+        'extra' => {}
       },
-      'structure' => {
-        'menu_child' => {
+      'node_directions' => {
+        'next' => {
           'cmdname' => 'node',
           'extra' => {
             'associated_section' => {
-              'cmdname' => 'section',
-              'extra' => {},
-              'structure' => {
-                'section_number' => '1.1'
+              'cmdname' => 'chapter',
+              'extra' => {
+                'section_number' => '1'
               }
             },
-            'normalized' => 'section'
-          },
-          'structure' => {
-            'node_up' => {}
+            'node_directions' => {
+              'prev' => {},
+              'up' => {}
+            },
+            'normalized' => 'chapter'
           }
-        },
-        'node_prev' => {},
-        'node_up' => {}
-      }
-    },
-    'node_next' => {}
-  }
-};
-$result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'};
-$result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'double_contents_after_title_show_title_nodes'};
-$result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'double_contents_after_title_show_title_nodes'};
-$result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'node_next'} = $result_nodes{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'};
-
-$result_menus{'double_contents_after_title_show_title_nodes'} = {
-  'cmdname' => 'node',
-  'extra' => {
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'normalized' => 'chapter'
-      },
-      'structure' => {
-        'menu_child' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'section'
-          },
-          'structure' => {
-            'menu_up' => {},
-            'menu_up_hash' => {
-              'chapter' => 1
-            }
-          }
-        },
-        'menu_up' => {},
-        'menu_up_hash' => {
-          'Top' => 1
         }
-      }
+      },
+      'normalized' => 'Top'
+    }
+  },
+  {},
+  {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'section',
+        'extra' => {
+          'section_number' => '1.1'
+        }
+      },
+      'node_directions' => {
+        'up' => {}
+      },
+      'normalized' => 'section'
     }
   }
-};
-$result_menus{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'};
-$result_menus{'double_contents_after_title_show_title_nodes'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'double_contents_after_title_show_title_nodes'};
+];
+$result_nodes{'double_contents_after_title_show_title_nodes'}[0]{'extra'}{'node_directions'}{'next'}{'extra'}{'node_directions'}{'prev'} = $result_nodes{'double_contents_after_title_show_title_nodes'}[0];
+$result_nodes{'double_contents_after_title_show_title_nodes'}[0]{'extra'}{'node_directions'}{'next'}{'extra'}{'node_directions'}{'up'} = $result_nodes{'double_contents_after_title_show_title_nodes'}[0];
+$result_nodes{'double_contents_after_title_show_title_nodes'}[1] = $result_nodes{'double_contents_after_title_show_title_nodes'}[0]{'extra'}{'node_directions'}{'next'};
+$result_nodes{'double_contents_after_title_show_title_nodes'}[2]{'extra'}{'node_directions'}{'up'} = $result_nodes{'double_contents_after_title_show_title_nodes'}[0]{'extra'}{'node_directions'}{'next'};
+
+$result_menus{'double_contents_after_title_show_title_nodes'} = [
+  {
+    'extra' => {
+      'menus' => [
+        {}
+      ],
+      'normalized' => 'Top'
+    }
+  },
+  {
+    'extra' => {
+      'menu_directions' => {
+        'up' => {}
+      },
+      'menus' => [
+        {}
+      ],
+      'normalized' => 'chapter'
+    }
+  },
+  {
+    'extra' => {
+      'menu_directions' => {
+        'up' => {}
+      },
+      'normalized' => 'section'
+    }
+  }
+];
+$result_menus{'double_contents_after_title_show_title_nodes'}[1]{'extra'}{'menu_directions'}{'up'} = $result_menus{'double_contents_after_title_show_title_nodes'}[0];
+$result_menus{'double_contents_after_title_show_title_nodes'}[2]{'extra'}{'menu_directions'}{'up'} = $result_menus{'double_contents_after_title_show_title_nodes'}[1];
 
 $result_errors{'double_contents_after_title_show_title_nodes'} = [];
 
