@@ -50,9 +50,7 @@ $result_trees{'include_setfilename_on_setfilename_line'} = {
                             }
                           },
                           'source_info' => {
-                            'file_name' => '',
-                            'line_nr' => 1,
-                            'macro' => ''
+                            'line_nr' => 1
                           }
                         }
                       ],
@@ -69,9 +67,7 @@ $result_trees{'include_setfilename_on_setfilename_line'} = {
                     }
                   },
                   'source_info' => {
-                    'file_name' => '',
-                    'line_nr' => 1,
-                    'macro' => ''
+                    'line_nr' => 1
                   }
                 }
               ],
@@ -88,9 +84,7 @@ $result_trees{'include_setfilename_on_setfilename_line'} = {
             }
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 1,
-            'macro' => ''
+            'line_nr' => 1
           }
         }
       ],
@@ -110,72 +104,56 @@ $result_errors{'include_setfilename_on_setfilename_line'} = [
   {
     'error_line' => 'warning: @setfilename should only appear at the beginning of a line
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@setfilename should only appear at the beginning of a line',
     'type' => 'warning'
   },
   {
     'error_line' => 'warning: @setfilename should not appear in @setfilename
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@setfilename should not appear in @setfilename',
     'type' => 'warning'
   },
   {
     'error_line' => 'warning: multiple @setfilename
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => 'multiple @setfilename',
     'type' => 'warning'
   },
   {
     'error_line' => 'warning: @include should only appear at the beginning of a line
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@include should only appear at the beginning of a line',
     'type' => 'warning'
   },
   {
     'error_line' => 'warning: @include should not appear in @setfilename
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@include should not appear in @setfilename',
     'type' => 'warning'
   },
   {
     'error_line' => '@include: could not find are you joking!
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => '@include: could not find are you joking!',
     'type' => 'error'
   },
   {
     'error_line' => 'bad argument to @setfilename: other file @include are you joking!
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => 'bad argument to @setfilename: other file @include are you joking!',
     'type' => 'error'
   },
   {
     'error_line' => 'bad argument to @setfilename: file @setfilename other file @include are you joking!
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => 'bad argument to @setfilename: file @setfilename other file @include are you joking!',
     'type' => 'error'
   }
