@@ -23,9 +23,7 @@ $result_errors{'lone_end_itemize'} = [
   {
     'error_line' => 'unmatched `@end itemize\'
 ',
-    'file_name' => '',
     'line_nr' => 1,
-    'macro' => '',
     'text' => 'unmatched `@end itemize\'',
     'type' => 'error'
   }
