@@ -12,57 +12,19 @@ $result_trees{'navigation_section_no_header'} = {
         {
           'contents' => [
             {
-              'contents' => [
-                {
-                  'text' => '\\input texinfo @c -*-texinfo-*-
+              'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'text_before_beginning'
-                },
-                {
-                  'text' => '
-',
-                  'type' => 'text_before_beginning'
-                }
-              ],
-              'type' => 'preamble_before_beginning'
-            }
-          ],
-          'type' => 'preamble_before_setfilename'
-        },
-        {
-          'contents' => [
-            {
-              'args' => [
-                {
-                  'contents' => [
-                    {
-                      'text' => 'navigation.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
-                  'type' => 'line_arg'
-                }
-              ],
-              'cmdname' => 'setfilename',
-              'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'navigation.info'
-              },
-              'source_info' => {
-                'file_name' => 'navigation.texi',
-                'line_nr' => 3,
-                'macro' => ''
-              }
+              'type' => 'text_before_beginning'
             },
             {
               'text' => '
 ',
-              'type' => 'empty_line'
+              'type' => 'text_before_beginning'
             }
           ],
+          'type' => 'preamble_before_beginning'
+        },
+        {
           'type' => 'preamble_before_content'
         }
       ],
@@ -76,33 +38,28 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'Top'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
       'extra' => {
-        'node_content' => [
-          {}
-        ],
-        'nodes_manuals' => [
-          {
-            'node_content' => [
-              {}
-            ],
-            'normalized' => 'Top'
-          }
-        ],
-        'normalized' => 'Top',
-        'spaces_before_argument' => ' '
+        'is_target' => 1,
+        'normalized' => 'Top'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 5,
-        'macro' => ''
+        'line_nr' => 3
       }
     },
     {
@@ -113,9 +70,11 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'File used for navigation testing'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
@@ -130,9 +89,11 @@ $result_trees{'navigation_section_no_header'} = {
         {
           'args' => [
             {
-              'extra' => {
-                'spaces_after_argument' => '
+              'info' => {
+                'spaces_after_argument' => {
+                  'text' => '
 '
+                }
               },
               'type' => 'block_line_arg'
             }
@@ -140,7 +101,7 @@ $result_trees{'navigation_section_no_header'} = {
           'cmdname' => 'menu',
           'contents' => [
             {
-              'args' => [
+              'contents' => [
                 {
                   'text' => '* ',
                   'type' => 'menu_entry_leading_text'
@@ -151,6 +112,14 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'chapter'
                     }
                   ],
+                  'extra' => {
+                    'node_content' => {
+                      'contents' => [
+                        {}
+                      ]
+                    },
+                    'normalized' => 'chapter'
+                  },
                   'type' => 'menu_entry_node'
                 },
                 {
@@ -172,19 +141,9 @@ $result_trees{'navigation_section_no_header'} = {
                   'type' => 'menu_entry_description'
                 }
               ],
-              'extra' => {
-                'menu_entry_description' => {},
-                'menu_entry_node' => {
-                  'node_content' => [
-                    {}
-                  ],
-                  'normalized' => 'chapter'
-                }
-              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 9,
-                'macro' => ''
+                'line_nr' => 7
               },
               'type' => 'menu_entry'
             },
@@ -196,29 +155,33 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'menu'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
+                  'info' => {
+                    'spaces_after_argument' => {
+                      'text' => '
 '
+                    }
                   },
                   'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' '
+                }
+              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 10,
-                'macro' => ''
+                'line_nr' => 8
               }
             }
           ],
           'source_info' => {
             'file_name' => 'navigation.texi',
-            'line_nr' => 8,
-            'macro' => ''
+            'line_nr' => 6
           }
         },
         {
@@ -227,13 +190,15 @@ $result_trees{'navigation_section_no_header'} = {
           'type' => 'empty_line'
         }
       ],
-      'extra' => {
-        'spaces_before_argument' => ' '
+      'extra' => {},
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 6,
-        'macro' => ''
+        'line_nr' => 4
       }
     },
     {
@@ -244,33 +209,28 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'chapter'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
       'extra' => {
-        'node_content' => [
-          {}
-        ],
-        'nodes_manuals' => [
-          {
-            'node_content' => [
-              {}
-            ],
-            'normalized' => 'chapter'
-          }
-        ],
-        'normalized' => 'chapter',
-        'spaces_before_argument' => ' '
+        'is_target' => 1,
+        'normalized' => 'chapter'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 12,
-        'macro' => ''
+        'line_nr' => 10
       }
     },
     {
@@ -281,9 +241,11 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'First chapter'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
@@ -298,9 +260,11 @@ $result_trees{'navigation_section_no_header'} = {
         {
           'args' => [
             {
-              'extra' => {
-                'spaces_after_argument' => '
+              'info' => {
+                'spaces_after_argument' => {
+                  'text' => '
 '
+                }
               },
               'type' => 'block_line_arg'
             }
@@ -308,7 +272,7 @@ $result_trees{'navigation_section_no_header'} = {
           'cmdname' => 'menu',
           'contents' => [
             {
-              'args' => [
+              'contents' => [
                 {
                   'text' => '* ',
                   'type' => 'menu_entry_leading_text'
@@ -319,6 +283,14 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'section'
                     }
                   ],
+                  'extra' => {
+                    'node_content' => {
+                      'contents' => [
+                        {}
+                      ]
+                    },
+                    'normalized' => 'section'
+                  },
                   'type' => 'menu_entry_node'
                 },
                 {
@@ -340,19 +312,9 @@ $result_trees{'navigation_section_no_header'} = {
                   'type' => 'menu_entry_description'
                 }
               ],
-              'extra' => {
-                'menu_entry_description' => {},
-                'menu_entry_node' => {
-                  'node_content' => [
-                    {}
-                  ],
-                  'normalized' => 'section'
-                }
-              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 16,
-                'macro' => ''
+                'line_nr' => 14
               },
               'type' => 'menu_entry'
             },
@@ -364,29 +326,33 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'menu'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
+                  'info' => {
+                    'spaces_after_argument' => {
+                      'text' => '
 '
+                    }
                   },
                   'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' '
+                }
+              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 17,
-                'macro' => ''
+                'line_nr' => 15
               }
             }
           ],
           'source_info' => {
             'file_name' => 'navigation.texi',
-            'line_nr' => 15,
-            'macro' => ''
+            'line_nr' => 13
           }
         },
         {
@@ -396,12 +362,16 @@ $result_trees{'navigation_section_no_header'} = {
         }
       ],
       'extra' => {
-        'spaces_before_argument' => ' '
+        'section_number' => '1'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 13,
-        'macro' => ''
+        'line_nr' => 11
       }
     },
     {
@@ -412,33 +382,28 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'section'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
       'extra' => {
-        'node_content' => [
-          {}
-        ],
-        'nodes_manuals' => [
-          {
-            'node_content' => [
-              {}
-            ],
-            'normalized' => 'section'
-          }
-        ],
-        'normalized' => 'section',
-        'spaces_before_argument' => ' '
+        'is_target' => 1,
+        'normalized' => 'section'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 19,
-        'macro' => ''
+        'line_nr' => 17
       }
     },
     {
@@ -449,9 +414,11 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'Section in chapter'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
@@ -652,9 +619,11 @@ $result_trees{'navigation_section_no_header'} = {
         {
           'args' => [
             {
-              'extra' => {
-                'spaces_after_argument' => '
+              'info' => {
+                'spaces_after_argument' => {
+                  'text' => '
 '
+                }
               },
               'type' => 'block_line_arg'
             }
@@ -662,7 +631,7 @@ $result_trees{'navigation_section_no_header'} = {
           'cmdname' => 'menu',
           'contents' => [
             {
-              'args' => [
+              'contents' => [
                 {
                   'text' => '* ',
                   'type' => 'menu_entry_leading_text'
@@ -673,6 +642,14 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'subsection'
                     }
                   ],
+                  'extra' => {
+                    'node_content' => {
+                      'contents' => [
+                        {}
+                      ]
+                    },
+                    'normalized' => 'subsection'
+                  },
                   'type' => 'menu_entry_node'
                 },
                 {
@@ -694,19 +671,9 @@ $result_trees{'navigation_section_no_header'} = {
                   'type' => 'menu_entry_description'
                 }
               ],
-              'extra' => {
-                'menu_entry_description' => {},
-                'menu_entry_node' => {
-                  'node_content' => [
-                    {}
-                  ],
-                  'normalized' => 'subsection'
-                }
-              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 50,
-                'macro' => ''
+                'line_nr' => 48
               },
               'type' => 'menu_entry'
             },
@@ -718,29 +685,33 @@ $result_trees{'navigation_section_no_header'} = {
                       'text' => 'menu'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
+                  'info' => {
+                    'spaces_after_argument' => {
+                      'text' => '
 '
+                    }
                   },
                   'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' '
+                }
+              },
               'source_info' => {
                 'file_name' => 'navigation.texi',
-                'line_nr' => 51,
-                'macro' => ''
+                'line_nr' => 49
               }
             }
           ],
           'source_info' => {
             'file_name' => 'navigation.texi',
-            'line_nr' => 49,
-            'macro' => ''
+            'line_nr' => 47
           }
         },
         {
@@ -750,12 +721,16 @@ $result_trees{'navigation_section_no_header'} = {
         }
       ],
       'extra' => {
-        'spaces_before_argument' => ' '
+        'section_number' => '1.1'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 20,
-        'macro' => ''
+        'line_nr' => 18
       }
     },
     {
@@ -766,33 +741,28 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'subsection'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
       'extra' => {
-        'node_content' => [
-          {}
-        ],
-        'nodes_manuals' => [
-          {
-            'node_content' => [
-              {}
-            ],
-            'normalized' => 'subsection'
-          }
-        ],
-        'normalized' => 'subsection',
-        'spaces_before_argument' => ' '
+        'is_target' => 1,
+        'normalized' => 'subsection'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 53,
-        'macro' => ''
+        'line_nr' => 51
       }
     },
     {
@@ -803,9 +773,11 @@ $result_trees{'navigation_section_no_header'} = {
               'text' => 'Sub section in section'
             }
           ],
-          'extra' => {
-            'spaces_after_argument' => '
+          'info' => {
+            'spaces_after_argument' => {
+              'text' => '
 '
+            }
           },
           'type' => 'line_arg'
         }
@@ -822,14 +794,14 @@ $result_trees{'navigation_section_no_header'} = {
             {
               'text' => '
 ',
-              'type' => 'misc_arg'
+              'type' => 'rawline_arg'
             }
           ],
           'cmdname' => 'contents',
+          'extra' => {},
           'source_info' => {
             'file_name' => 'navigation.texi',
-            'line_nr' => 56,
-            'macro' => ''
+            'line_nr' => 54
           }
         },
         {
@@ -839,12 +811,16 @@ $result_trees{'navigation_section_no_header'} = {
         }
       ],
       'extra' => {
-        'spaces_before_argument' => ' '
+        'section_number' => '1.1.1'
+      },
+      'info' => {
+        'spaces_before_argument' => {
+          'text' => ' '
+        }
       },
       'source_info' => {
         'file_name' => 'navigation.texi',
-        'line_nr' => 54,
-        'macro' => ''
+        'line_nr' => 52
       }
     },
     {
@@ -852,7 +828,7 @@ $result_trees{'navigation_section_no_header'} = {
         {
           'text' => '
 ',
-          'type' => 'misc_arg'
+          'type' => 'rawline_arg'
         }
       ],
       'cmdname' => 'bye'
@@ -860,25 +836,12 @@ $result_trees{'navigation_section_no_header'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'navigation_section_no_header'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'args'}[3];
-$result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'args'}[1]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_section_no_header'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[7]{'args'}[0]{'contents'}[0];
+$result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}{'contents'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}{'contents'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0];
+$result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'contents'}[1]{'extra'}{'node_content'}{'contents'}[0] = $result_trees{'navigation_section_no_header'}{'contents'}[6]{'contents'}[27]{'contents'}[0]{'contents'}[1]{'contents'}[0];
 
 $result_texis{'navigation_section_no_header'} = '\\input texinfo @c -*-texinfo-*-
 
-@setfilename navigation.info
-
 @node Top
 @top File used for navigation testing
 
@@ -936,8 +899,7 @@ b b b b b b b b b b b b b b b b  b b b b b bb b b b b b b  bb  b bb.
 ';
 
 
-$result_texts{'navigation_section_no_header'} = '
-File used for navigation testing
+$result_texts{'navigation_section_no_header'} = 'File used for navigation testing
 ********************************
 
 * chapter::
@@ -986,7 +948,7 @@ b b b b b b b b b b b b b b b b  b b b b b bb b b b b b b  bb  b bb.
 ';
 
 $result_sectioning{'navigation_section_no_header'} = {
-  'structure' => {
+  'extra' => {
     'section_childs' => [
       {
         'cmdname' => 'top',
@@ -995,11 +957,8 @@ $result_sectioning{'navigation_section_no_header'} = {
             'cmdname' => 'node',
             'extra' => {
               'normalized' => 'Top'
-            },
-            'structure' => {}
-          }
-        },
-        'structure' => {
+            }
+          },
           'section_childs' => [
             {
               'cmdname' => 'chapter',
@@ -1008,11 +967,8 @@ $result_sectioning{'navigation_section_no_header'} = {
                   'cmdname' => 'node',
                   'extra' => {
                     'normalized' => 'chapter'
-                  },
-                  'structure' => {}
-                }
-              },
-              'structure' => {
+                  }
+                },
                 'section_childs' => [
                   {
                     'cmdname' => 'section',
@@ -1021,11 +977,8 @@ $result_sectioning{'navigation_section_no_header'} = {
                         'cmdname' => 'node',
                         'extra' => {
                           'normalized' => 'section'
-                        },
-                        'structure' => {}
-                      }
-                    },
-                    'structure' => {
+                        }
+                      },
                       'section_childs' => [
                         {
                           'cmdname' => 'subsection',
@@ -1034,177 +987,162 @@ $result_sectioning{'navigation_section_no_header'} = {
                               'cmdname' => 'node',
                               'extra' => {
                                 'normalized' => 'subsection'
-                              },
-                              'structure' => {}
-                            }
-                          },
-                          'structure' => {
+                              }
+                            },
+                            'section_directions' => {
+                              'up' => {}
+                            },
                             'section_level' => 3,
-                            'section_number' => '1.1.1',
-                            'section_up' => {}
+                            'section_number' => '1.1.1'
                           }
                         }
                       ],
+                      'section_directions' => {
+                        'up' => {}
+                      },
                       'section_level' => 2,
-                      'section_number' => '1.1',
-                      'section_up' => {}
+                      'section_number' => '1.1'
                     }
                   }
                 ],
+                'section_directions' => {
+                  'up' => {}
+                },
                 'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
+                'section_number' => '1',
+                'toplevel_directions' => {
+                  'prev' => {},
+                  'up' => {}
+                }
               }
             }
           ],
           'section_level' => 0,
-          'section_up' => {}
+          'sectioning_root' => {},
+          'toplevel_directions' => {}
         }
       }
     ],
     'section_level' => -1
   }
 };
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'navigation_section_no_header'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'navigation_section_no_header'};
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_directions'}{'up'} = $result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0];
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_directions'}{'up'} = $result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0];
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'section_directions'}{'up'} = $result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'toplevel_directions'}{'prev'} = $result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'section_childs'}[0]{'extra'}{'toplevel_directions'}{'up'} = $result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0];
+$result_sectioning{'navigation_section_no_header'}{'extra'}{'section_childs'}[0]{'extra'}{'sectioning_root'} = $result_sectioning{'navigation_section_no_header'};
 
-$result_nodes{'navigation_section_no_header'} = {
-  'cmdname' => 'node',
-  'extra' => {
-    'associated_section' => {
-      'cmdname' => 'top',
-      'extra' => {},
-      'structure' => {}
-    },
-    'menus' => [
-      {
-        'cmdname' => 'menu'
-      }
-    ],
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'associated_section' => {
-          'cmdname' => 'chapter',
-          'extra' => {},
-          'structure' => {
-            'section_number' => 1
-          }
-        },
-        'menus' => [
-          {
-            'cmdname' => 'menu'
-          }
-        ],
-        'normalized' => 'chapter'
+$result_nodes{'navigation_section_no_header'} = [
+  {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'top',
+        'extra' => {}
       },
-      'structure' => {
-        'menu_child' => {
+      'node_directions' => {
+        'next' => {
           'cmdname' => 'node',
           'extra' => {
             'associated_section' => {
-              'cmdname' => 'section',
-              'extra' => {},
-              'structure' => {
-                'section_number' => '1.1'
-              }
-            },
-            'menus' => [
-              {
-                'cmdname' => 'menu'
-              }
-            ],
-            'normalized' => 'section'
-          },
-          'structure' => {
-            'menu_child' => {
-              'cmdname' => 'node',
+              'cmdname' => 'chapter',
               'extra' => {
-                'associated_section' => {
-                  'cmdname' => 'subsection',
-                  'extra' => {},
-                  'structure' => {
-                    'section_number' => '1.1.1'
-                  }
-                },
-                'normalized' => 'subsection'
-              },
-              'structure' => {
-                'node_up' => {}
+                'section_number' => '1'
               }
             },
-            'node_up' => {}
-          }
-        },
-        'node_prev' => {},
-        'node_up' => {}
-      }
-    },
-    'node_next' => {}
-  }
-};
-$result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'};
-$result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'};
-$result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'navigation_section_no_header'};
-$result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'navigation_section_no_header'};
-$result_nodes{'navigation_section_no_header'}{'structure'}{'node_next'} = $result_nodes{'navigation_section_no_header'}{'structure'}{'menu_child'};
-
-$result_menus{'navigation_section_no_header'} = {
-  'cmdname' => 'node',
-  'extra' => {
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'normalized' => 'chapter'
-      },
-      'structure' => {
-        'menu_child' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'section'
-          },
-          'structure' => {
-            'menu_child' => {
-              'cmdname' => 'node',
-              'extra' => {
-                'normalized' => 'subsection'
-              },
-              'structure' => {
-                'menu_up' => {},
-                'menu_up_hash' => {
-                  'section' => 1
-                }
-              }
+            'node_directions' => {
+              'prev' => {},
+              'up' => {}
             },
-            'menu_up' => {},
-            'menu_up_hash' => {
-              'chapter' => 1
-            }
+            'normalized' => 'chapter'
           }
-        },
-        'menu_up' => {},
-        'menu_up_hash' => {
-          'Top' => 1
         }
-      }
+      },
+      'normalized' => 'Top'
+    }
+  },
+  {},
+  {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'section',
+        'extra' => {
+          'section_number' => '1.1'
+        }
+      },
+      'node_directions' => {
+        'up' => {}
+      },
+      'normalized' => 'section'
+    }
+  },
+  {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'subsection',
+        'extra' => {
+          'section_number' => '1.1.1'
+        }
+      },
+      'node_directions' => {
+        'up' => {}
+      },
+      'normalized' => 'subsection'
     }
   }
-};
-$result_menus{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'};
-$result_menus{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'navigation_section_no_header'}{'structure'}{'menu_child'};
-$result_menus{'navigation_section_no_header'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'navigation_section_no_header'};
+];
+$result_nodes{'navigation_section_no_header'}[0]{'extra'}{'node_directions'}{'next'}{'extra'}{'node_directions'}{'prev'} = $result_nodes{'navigation_section_no_header'}[0];
+$result_nodes{'navigation_section_no_header'}[0]{'extra'}{'node_directions'}{'next'}{'extra'}{'node_directions'}{'up'} = $result_nodes{'navigation_section_no_header'}[0];
+$result_nodes{'navigation_section_no_header'}[1] = $result_nodes{'navigation_section_no_header'}[0]{'extra'}{'node_directions'}{'next'};
+$result_nodes{'navigation_section_no_header'}[2]{'extra'}{'node_directions'}{'up'} = $result_nodes{'navigation_section_no_header'}[0]{'extra'}{'node_directions'}{'next'};
+$result_nodes{'navigation_section_no_header'}[3]{'extra'}{'node_directions'}{'up'} = $result_nodes{'navigation_section_no_header'}[2];
+
+$result_menus{'navigation_section_no_header'} = [
+  {
+    'extra' => {
+      'menus' => [
+        {}
+      ],
+      'normalized' => 'Top'
+    }
+  },
+  {
+    'extra' => {
+      'menu_directions' => {
+        'up' => {}
+      },
+      'menus' => [
+        {}
+      ],
+      'normalized' => 'chapter'
+    }
+  },
+  {
+    'extra' => {
+      'menu_directions' => {
+        'up' => {}
+      },
+      'menus' => [
+        {}
+      ],
+      'normalized' => 'section'
+    }
+  },
+  {
+    'extra' => {
+      'menu_directions' => {
+        'up' => {}
+      },
+      'normalized' => 'subsection'
+    }
+  }
+];
+$result_menus{'navigation_section_no_header'}[1]{'extra'}{'menu_directions'}{'up'} = $result_menus{'navigation_section_no_header'}[0];
+$result_menus{'navigation_section_no_header'}[2]{'extra'}{'menu_directions'}{'up'} = $result_menus{'navigation_section_no_header'}[1];
+$result_menus{'navigation_section_no_header'}[3]{'extra'}{'menu_directions'}{'up'} = $result_menus{'navigation_section_no_header'}[2];
 
 $result_errors{'navigation_section_no_header'} = [];
 
