@@ -54,9 +54,7 @@ $result_trees{'macro_in_ifset'} = {
                 }
               },
               'source_info' => {
-                'file_name' => '',
-                'line_nr' => 3,
-                'macro' => ''
+                'line_nr' => 3
               }
             }
           ],
@@ -65,9 +63,7 @@ $result_trees{'macro_in_ifset'} = {
 '
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 1,
-            'macro' => ''
+            'line_nr' => 1
           }
         },
         {
@@ -130,9 +126,7 @@ $result_trees{'macro_in_ifset'} = {
                       }
                     },
                     'source_info' => {
-                      'file_name' => '',
-                      'line_nr' => 8,
-                      'macro' => ''
+                      'line_nr' => 8
                     }
                   }
                 ],
@@ -142,9 +136,7 @@ $result_trees{'macro_in_ifset'} = {
                   }
                 },
                 'source_info' => {
-                  'file_name' => '',
-                  'line_nr' => 5,
-                  'macro' => ''
+                  'line_nr' => 5
                 }
               },
               'position' => 1,
