@@ -17,21 +17,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => '
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => '
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 1,
-            'macro' => ''
+            'line_nr' => 1
           }
         },
         {
@@ -51,21 +51,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => ' 
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' 
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 4,
-            'macro' => ''
+            'line_nr' => 4
           }
         },
         {
@@ -85,7 +85,7 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             },
             {
               'contents' => [
@@ -93,21 +93,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'b'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => '
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => '
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 7,
-            'macro' => ''
+            'line_nr' => 7
           }
         },
         {
@@ -127,7 +127,7 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             },
             {
               'contents' => [
@@ -135,21 +135,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'b'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => ' 
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' 
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 10,
-            'macro' => ''
+            'line_nr' => 10
           }
         },
         {
@@ -169,7 +169,7 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             },
             {
               'contents' => [
@@ -177,21 +177,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => ' b'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => '
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => '
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 13,
-            'macro' => ''
+            'line_nr' => 13
           }
         },
         {
@@ -211,7 +211,7 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => 'a'
                 }
               ],
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             },
             {
               'contents' => [
@@ -219,21 +219,21 @@ $result_trees{'brace_commands_spaces_end_of_lines'} = {
                   'text' => ' b'
                 }
               ],
-              'extra' => {
-                'spaces_before_argument' => ' 
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' 
 '
+                }
               },
-              'type' => 'brace_command_arg'
+              'type' => 'brace_arg'
             }
           ],
           'cmdname' => 'image',
           'extra' => {
-            'input_perl_encoding' => 'utf-8'
+            'input_encoding_name' => 'utf-8'
           },
           'source_info' => {
-            'file_name' => '',
-            'line_nr' => 16,
-            'macro' => ''
+            'line_nr' => 16
           }
         },
         {
